@@ -1,18 +1,18 @@
 #' Run covr on a package and upload the result to codecov.io
-#' @param coverage an existing coverage object to submit, if \code{NULL},
-#' \code{\link{package_coverage}} will be called with the arguments from
-#' \code{...}
-#' @param ... arguments passed to \code{\link{package_coverage}}
+#' @param coverage an existing coverage object to submit, if `NULL`,
+#' [package_coverage()] will be called with the arguments from
+#' `...`
+#' @param ... arguments passed to [package_coverage()]
 #' @param base_url Codecov url (change for Enterprise)
-#' @param quiet if \code{FALSE}, print the coverage before submission.
-#' @param token a codecov upload token, if \code{NULL} the environment
+#' @param quiet if `FALSE`, print the coverage before submission.
+#' @param token a codecov upload token, if `NULL` the environment
 #' variable \sQuote{CODECOV_TOKEN} is used.
 #' @param commit explicitly set the commit this coverage result object
 #' corresponds to. Is looked up from the service or locally if it is
-#' \code{NULL}.
+#' `NULL`.
 #' @param branch explicitly set the branch this coverage result object
 #' corresponds to, this is looked up from the service or locally if it is
-#' \code{NULL}.
+#' `NULL`.
 #' @export
 #' @examples
 #' \dontrun{
@@ -49,7 +49,7 @@ codecov <- function(...,
   # Travis CI
   # ---------
   } else if (Sys.getenv("CI") == "true" && Sys.getenv("TRAVIS") == "true") {
-    # http://docs.travis-ci.com/user/ci-environment/#Environment-variables
+    # https://docs.travis-ci.com/user/environment-variables/#Default-Environment-Variables
     codecov_url <- paste0(base_url, "/upload/v2") # nolint
     codecov_query <- list(branch = branch %||% Sys.getenv("TRAVIS_BRANCH"),
                           service = "travis",
@@ -112,12 +112,11 @@ codecov <- function(...,
   } else if (Sys.getenv("CI") == "True" && Sys.getenv("APPVEYOR") == "True") {
     # http://www.appveyor.com/docs/environment-variables
     codecov_url <- paste0(base_url, "/upload/v2") # nolint
-    name_info <- strsplit(Sys.getenv("APPVEYOR_REPO_NAME"), "/")[[1]]
     codecov_query <- list(service = "appveyor",
                           branch = branch %||% Sys.getenv("APPVEYOR_REPO_BRANCH"),
-                          build = Sys.getenv("APPVEYOR_BUILD_NUMBER"),
-                          owner = name_info[1],
-                          repo = name_info[2],
+                          job = paste(Sys.getenv("APPVEYOR_ACCOUNT_NAME"), Sys.getenv("APPVEYOR_PROJECT_SLUG"), Sys.getenv("APPVEYOR_BUILD_VERSION"), sep = "/"),
+                          build = Sys.getenv("APPVEYOR_JOB_ID"),
+                          slug = Sys.getenv("APPVEYOR_REPO_NAME"),
                           commit = commit %||% Sys.getenv("APPVEYOR_REPO_COMMIT"))
   # -------
   # Wercker
